# zpp_store

## Informations

Outil de srialisation d'objet Python.
Il peut prendre en charge:
- les formats classiques: str, int, float, bool, type, none, complex, bytes, decimal
- les formats structurs: list, dict, tuple, array, bytearray, frozenset
- les formats io: BytesIO, StringIO, TextIOWrapper, BufferedReader
- les objets: Class, datetime, function, builtin function

Le fichier de sortie peut-tre soit un yaml, soit un fichier binaire; et celui-ci peut tre chiffr avec un mot de passe.
Le systme fonctionne comme un coffre dans lequel on peut stocker plusieurs donnes et utilise le systme cl/valeur pour identifier les donnes.

Il intgre galement un outil pour stocker des donnes sous forme de Class pour les structurer et faciliter leurs manipulations.

### Prrequis
- Python 3

## Installation


```shell
pip install zpp_store
```

## Utilisation
### Initialisation du connecteur

Le store est accessible de deux faons:
- En initialisant le store dans une variable
```python
import zpp_store

vault = zpp_store.Store()
```
- Ou avec la mthode **with**
```python
import zpp_store

with zpp_store.Store() as vault:
	'''Traitement'''
```

La Classe Store peut prendre plusieurs arguments:
- ***filename***: pour spcifier le fichier de sortie
	Si le fichier de sortie n'est pas prcis, le rsultat restera dans le stockage de la classe. Il sera alors possible de rcuprer le rsultat avec la mthode **get_content()**
- ***protected***: pour spcifier si le fichier doit tre chiffr (si le mot de passe n'est pas spcifi. Un prompt demandera le mot de passe)
- ***password***: pour spcifier le mot de passe pour le chiffrement (active protected)
- ***format***: pour spcifier le format de sortie. **zpp_store.Formatstore.to_yaml**, **zpp_store.Formatstore.to_binary** ou **zpp_store.Formatstore.to_dict**. 
	Attention, le format to_dict n'accepte pas la sortie dans un fichier.
<br>

###  Srialisation de donnes

Pour srialiser des donnes, il suffit d'appeler la classe **Store** et d'utiliser la mthode **push** avec comme paramtre le nom de la cl  utiliser et la donne  srialiser.

```python
import zpp_store

class Person:
	def __init__(self, name, age, city):
		self.name = name
		self.age = age
		self.city = city

new_person = Person("Bob", 35, "Paris")

with zpp_store.Store() as vault:
	vault.push("utilisateur_bob", new_person)
```
<br>

###  Dsrialisation de donnes

Pour dsrialiser des donnes, il suffit d'appeler la classe **Store** et d'utiliser la mthode **pull** avec comme paramtre le nom de la cl  rcuprer.

```python
import zpp_store

class Person:
	def __init__(self, name, age, city):
		self.name = name
		self.age = age
		self.city = city

with zpp_store.Store() as vault:
	new_person = vault.pull("utilisateur_bob")
```
<br>

### Suppression de donnes

Il est possible de supprimer des donnes avec la mthode **erase()** en prcisant en paramtre la cl.

```python
import zpp_store

with zpp_store.Store() as vault:
	vault.erase("utilisateur_bob")
```

La mthode retournera alors **True** si une donne a t supprime, sinon **False**.
<br>

### Structuration de donnes

Il est possible de structurer un dictionnaire pour le transformer en **DataStore** et pour nous permettre de manipuler ces donnes comme une Class avec a.b.c
Pour cela, il nous suffit d'appeler la mthode **structure()** avec comme argument le dictionnaire

```python
import zpp_store

dict_data = {"Bonjour": "Hello world", "Data": {"insert": True, "false": True}}

data = zpp_store.structure(dict_data)
```

Le dictionnaire devient alors un **zpp_store.structure.DataStore**

Pour permettre de contrler la modification, le DataStore permet de rcuprer un hash du contenu avec la mthode **get_hash()**

```python
import zpp_store

dict_data = {"Bonjour": "Hello world", "Data": {"insert": True, "false": True}}

data = zpp_store.structure(dict_data)
hash_dict = data.get_hash()
```
<br>

### Dstructuration de donnes

Pour rcuprer un dictionnaire  partir d'un **DataStore**, il suffit d'appeler la mthode **destructure()**.

```python
import zpp_store

data = zpp_store.destructure(datastore)
```